@@ -1,9 +1,7 @@
 import igraph as ig
-import random, pickle
-from pathlib import Path
+import random
 import numpy as np
 #import matplotlib.pyplot as plt
-from collections import Counter
 try:
     from ctns.steps import step
 except ImportError as e:
@@ -64,54 +62,6 @@ def reset_network(G):
         node["test_result"] = -1
         node["symptoms"] = list()  
 
-def dump_simulation(nets, path, dump_type):
-    """
-    Dump the simulation to a pickle file
-    
-    Parameters
-    ----------
-    nets: list
-        List of ig.Graph()
-
-    path: string
-        The file path
-
-    dump_type: string
-        Can be either ["full", "light"]. In the first case, the full simulation is dumped.
-        Otherwise, only a report about node status is saved
-
-    Return
-    ------
-    None. The function saves a picke file containing:
-        - a list of ig.Graph() if dump_type is full
-        - a dict[i][j][attribute] where i is the step index, j is the node index and attribute can either be [agent_status, test_result, quarantine]
-
-    """
-
-    if dump_type == "full":
-        try:
-            with open(Path(path + ".pickle"), "wb") as f:
-                pickle.dump(nets, f, protocol = pickle.HIGHEST_PROTOCOL)
-        except:
-            print("Simulation is too big to be dumped, try dumping in separated files. Note that this operation will be slow")
-            try:
-                for i in range(len(nets)):
-                    net.write_picklez(fname = Path(path + "_network{}.pickle".format(i)), version = pickle.HIGHEST_PROTOCOL)
-            except:
-                print("Cannot dump network, the single network is too big. Please deactivate the dump option")
-                sys.exit(-1)
-    else:
-        to_dump = dict()
-        for i in range(len(nets)):
-            to_dump[i] = dict()
-            for j in range(len(list(nets[i].vs))):
-                to_dump[i][j] = dict()
-                to_dump[i][j]["agent_status"] = nets[i].vs[j]["agent_status"]
-                to_dump[i][j]["test_result"] = nets[i].vs[j]["test_result"]
-                to_dump[i][j]["quarantine"] = nets[i].vs[j]["quarantine"]
-        with open(Path(path + ".pickle"), "wb") as f:
-            pickle.dump(to_dump, f, protocol = pickle.HIGHEST_PROTOCOL)
-
 def compute_TR(G, R_0, infection_duration, incubation_days):
     """
     Compute the transmission rate of the disease in the network.
@@ -149,6 +99,49 @@ def compute_TR(G, R_0, infection_duration, incubation_days):
     reset_network(G)
     return R_0 /((infection_duration - incubation_days) * (sum(avr_deg) / len(avr_deg)))
 
+def update_dump_report(to_dump, net):
+    """
+    Update the simulation dump in case light dump is selected
+    
+    Parameters
+    ----------
+    to_dump: dict
+        Old dump doctionary
+
+    net: ig.Graph()
+        The contact network
+
+    Return
+    ------
+    to_dump: dict
+        Updated dump doctionary
+
+    """
+
+    network_report = Counter(net.vs["agent_status"])
+    tested = 0
+    positive = 0
+    quarantined = 0
+    for node in net.vs:
+        if node["test_result"] != -1:
+            tested += 1
+        if node["test_result"] == 1:
+            positive += 1
+        if node["quarantine"] != 0:
+            quarantined += 1
+
+    to_dump['S'].append(network_report['S'])
+    to_dump['E'].append(network_report['E'])
+    to_dump['I'].append(network_report['I'])
+    to_dump['R'].append(network_report['R'])
+    to_dump['D'].append(network_report['D'])
+    to_dump['quarantined'].append(quarantined)
+    to_dump['positive'].append(positive)
+    to_dump['tested'].append(tested)
+    to_dump['total'].append(sum(network_report.values()))
+
+    return to_dump
+
 '''
 
 def plot_degree_dist(G, node_sociability = None, edge_category = None, title = None, path = None):
